flex_pid

package
v0.0.0-...-27e1478 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2026 License: AGPL-3.0 Imports: 12 Imported by: 0

Documentation

Overview

Toepid – totally over-engineered PID control

Copyright (C) 2024–2025 Torsten Bronger, bronger@physik.rwth-aachen.de

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ControlParamsSet

type ControlParamsSet map[float64]pid.ControlParams

type Controller

type Controller struct {
	pid.Controller
	// contains filtered or unexported fields
}

func NewController

func NewController(logger tbr_logging.Logger, conType int, window float64, resetTime time.Duration,
	params ControlParamsSet) (c Controller)

func (*Controller) GetPreload

func (c *Controller) GetPreload() pid.UncertainFloat

func (*Controller) MarshalBinary

func (c *Controller) MarshalBinary() (data []byte, err error)

MarshalBinary writes the state of the controller. Note that this does not include parameters which are part of the configuration but only things that are touched when the code is running, e.g. time series data.

func (*Controller) StartPreloadListener

func (c *Controller) StartPreloadListener(ctx context.Context, topic string, errs chan<- error) paho.MessageHandler

func (*Controller) UnmarshalBinary

func (c *Controller) UnmarshalBinary(data []byte) error

UnmarshalBinary reads the state of the controller. Note that this does not include parameters which are part of the configuration but only things that are touched when the code is running, e.g. time series data. It reads data written by “MarshalBinary”.

Jump to